@@ -50,16 +50,14 @@ class Channel:
     #     await self.send_command(f'ban {user}')
 
     async def update_loop(self):
+        from .config import cfg
         if get_client_id() != 'CLIENT_ID':
             while True:
                 await self.chatters.update()
                 await self.stats.update()
                 self.is_mod = get_nick().lower() in self.chatters.mods
                 self.is_vip = get_nick().lower() in self.chatters.vips
-                await asyncio.sleep(60)
-
-    def start_update_loop(self):
-        asyncio.get_event_loop().create_task(self.update_loop())
+                await asyncio.sleep(120)  # update viewers every 2 minutes
 
     async def ban(self, user: str, reason: str = ''):
         """purges a user's messages then permabans them from the channel"""
@@ -67,7 +65,7 @@ class Channel:
 
     async def timeout(self, user: str, duration: int = 600):
         """
-        purges a user's messages then timeout out (makes them unable to chat)
+        purges a user's messages then times out the user (makes them unable to chat)
         for the specified duration (default 600 seconds)
         """
         await self.send_command(f'timeout {user} {duration}')
